frereth.weald.specs

This is really for the sake of shared specs

This is really for the sake of shared specs
raw docstring

log-level-valuesclj/s

name -> priority to assist in prioritizing and filtering

name -> priority to assist in prioritizing and filtering
raw docstring

log-levelsclj/s


Loggerclj/s≠protocol

Extend this for logging side-effects

Extend this for logging side-effects

flush!clj/s

(flush! this)

Some loggers need to do this at the end of a batch

Some loggers need to do this at the end of a batch

log!clj/s

(log! this msg)

At least queue up a log message to side-effect

At least queue up a log message to side-effect
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries