This is really for the sake of shared specs
This is really for the sake of shared specs
name -> priority to assist in prioritizing and filtering
name -> priority to assist in prioritizing and filtering
Extend this for logging side-effects
Extend this for logging side-effects
(flush! this)Some loggers need to do this at the end of a batch
Some loggers need to do this at the end of a batch
(log! this msg)At least queue up a log message to side-effect
At least queue up a log message to side-effect
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |